@@ -195,7 +195,7 @@ def star(t, size, fill=True, flag=True):
         t.end_fill()
 
 
-def randco(x=None, y=None):
+def randco(minx=None, miny=None):
     '''
     生成绘图窗范围内的随机坐标
 
@@ -206,12 +206,12 @@ def randco(x=None, y=None):
     scr = turtle.getscreen()
     w = scr.window_width()
     h = scr.window_height()
-    if x is None:
-        x = -w // 2
-    if y is None:
-        y = -h // 2
-    xpos = randint(x, w // 2)
-    ypos = randint(y, h // 2)
+    if minx is None:
+        minx = -w // 2
+    if miny is None:
+        miny = -h // 2
+    xpos = randint(minx, w // 2)
+    ypos = randint(miny, h // 2)
     return (xpos, ypos)
 
 
